@@ -2,12 +2,11 @@ from simpler._version import __version__
 from simpler.algorithms import DynamicProgramming
 from simpler.bioinformatics import codon_table, monoisotopic_mass_table, monoisotopic_mass_water, parse_fasta, dna_to_rna, rna_to_dna, rna_to_protein, reverse_complement
 from simpler.connectors import SQL, Excel
-from simpler.files import cwd, load, save, disk_cache, mem_cache, clear_global_mem_cache, size, find_hidden_compressed, tvshow_rename, directory_compare, decompress
+from simpler.files import cwd, load, save, disk_cache, mem_cache, clear_global_mem_cache, size, find_hidden_compressed, tvshow_rename, directory_compare, decompress, import_from_path
 from simpler.format import human_bytes, human_seconds, human_date, random_string, print_matrix, safe_filename
 from simpler.mail import compose, send
 from simpler.math import clamp, snap, unique, all_equal, jaccard, levenshtein, base_change, prime_list, is_prime, fibonacci, lcm, gcd, factor, palindrome_list, phi, date_range
 from simpler.profiling import tic, toc, deep_size
-from simpler.reflection import import_from_path
 from simpler.sparql import dbpedia, entity_types
 from simpler.terminal import getch, cprint
 from simpler.tests import Test, Suite
